CH_FEVT_C_ADV: CH_FEVT_C_ADV Children with fever for whom advice or...

View source: R/CH_FEVT_C_ADV.R

CH_FEVT_C_ADVR Documentation

CH_FEVT_C_ADV Children with fever for whom advice or treatment was sought ch_fev_care in github ml_fev_care should produce the same data KR

Description

CH_FEVT_C_ADV Children with fever for whom advice or treatment was sought ch_fev_care in github ml_fev_care should produce the same data KR

Usage

CH_FEVT_C_ADV(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "CH_FEVT_C_ADV", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.