CM_ECMR_C_IMF: CM_ECMR_C_IMF imr 5 years prior to survey.

View source: R/CM_ECMR_C_IMF.R

CM_ECMR_C_IMFR Documentation

CM_ECMR_C_IMF imr 5 years prior to survey.

Description

BR

Usage

CM_ECMR_C_IMF(Rdata, mort.cut = c(1, 2, 6, 12, 24, 36, 48, 60), mort.year = 5)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

mort.cut

age group cutoffs for hazard calculation. Constant hazards are assumed to be within the specified cutoffs.

mort.year

The number of years preceding survey. Set to be 5.

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "CM_ECMR_C_IMF", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.