CM_ECMR_C_NNR: CM_ECMR_C_NNR BRdata Neonatal mortality rate

View source: R/CM_ECMR_C_NNR.R

CM_ECMR_C_NNRR Documentation

CM_ECMR_C_NNR BRdata Neonatal mortality rate

Description

CM_ECMR_C_NNR BRdata Neonatal mortality rate

Usage

CM_ECMR_C_NNR(Rdata, nmr.year = 10)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

nmr.year

This is an argument specifically for NMR calculation. It specifies births how many years do we include prior to the date of survey. Default to be 10, i.e., NMR in the last 10 years prior to survey.

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "CM_ECMR_C_NNR",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::CM_ECMR_C_NNR)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.