CN_ANMC_C_ANY: CN_ANMC_C_ANY PRdata Children with any anemia Children under...

View source: R/CN_ANMC_C_ANY.R

CN_ANMC_C_ANYR Documentation

CN_ANMC_C_ANY PRdata Children with any anemia Children under five with any anemia

Description

CN_ANMC_C_ANY PRdata Children with any anemia Children under five with any anemia

Usage

CN_ANMC_C_ANY(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "CN_ANMC_C_ANY",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::CN_ANMC_C_ANY)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.