CN_BRFS_C_EXB: CN_BRFS_C_EXB KRdata Children exclusively breastfed...

View source: R/CN_BRFS_C_EXB.R

CN_BRFS_C_EXBR Documentation

CN_BRFS_C_EXB KRdata Children exclusively breastfed Prevalence of exclusive breastfeeding of children under six months of age

Description

CN_BRFS_C_EXB KRdata Children exclusively breastfed Prevalence of exclusive breastfeeding of children under six months of age

Usage

CN_BRFS_C_EXB(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "CN_BRFS_C_EXB",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::CN_BRFS_C_EXB)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.