CN_IYCF_C_4FA: CN_IYCF_C_4FA Percentage of children age 6-23 months fed five...

View source: R/CN_IYCF_C_4FA.R

CN_IYCF_C_4FAR Documentation

CN_IYCF_C_4FA Percentage of children age 6-23 months fed five or more food groups. The food groups are a. breastmilk b. infant formula, milk other than breast milk, cheese or yogurt or other milk products; c. foods made from grains, roots, and tubers, including porridge and fortified baby food from grains; d. vitamin A-rich fruits and vegetables (and red palm oil); e. other fruits and vegetables; f. eggs; g. meat, poultry, fish, and shellfish (and organ meats); h. legumes and nuts. nt_mdd in github KR

Description

CN_IYCF_C_4FA Percentage of children age 6-23 months fed five or more food groups. The food groups are a. breastmilk b. infant formula, milk other than breast milk, cheese or yogurt or other milk products; c. foods made from grains, roots, and tubers, including porridge and fortified baby food from grains; d. vitamin A-rich fruits and vegetables (and red palm oil); e. other fruits and vegetables; f. eggs; g. meat, poultry, fish, and shellfish (and organ meats); h. legumes and nuts. nt_mdd in github KR

Usage

CN_IYCF_C_4FA(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "CN_IYCF_C_4FA", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.