DV_AFSV_W_A12: DV_AFSV_W_A12

View source: R/DV_AFSV_W_A12.R

DV_AFSV_W_A12R Documentation

DV_AFSV_W_A12

Description

DV_AFSV_W_A12

Usage

DV_AFSV_W_A12(IRdata)

Arguments

IRdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "DV_AFSV_W_A12", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.