View source: R/DV_EXPV_W_12M.R
| DV_EXPV_W_12M | R Documentation |
DV_EXPV_W_12M Percentage of women who have experienced physical violence in the past 12 months often or sometimes dv_phy_12m in github IR
DV_EXPV_W_12M(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "DV_EXPV_W_12M", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.