View source: R/DV_EXSV_W_EVR.R
| DV_EXSV_W_EVR | R Documentation |
DV_EXSV_W_EVR Percentage of women who ever experienced sexual violence dv_sex in github IR
DV_EXSV_W_EVR(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "DV_EXSV_W_EVR", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.