View source: R/FP_CUSM_W_MOD.R
| FP_CUSM_W_MOD | R Documentation |
FP_CUSM_W_MOD IRdata Modern contraceptive prevalence rate (Married women currently using any modern method of contraception)
FP_CUSM_W_MOD(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "FP_CUSA_W_MOD",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::FP_CUSM_W_MOD)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.