FP_NADM_W_UNT: FP_NADM_W_UNT #unmet_family IRdata Married women with an...

View source: R/FP_NADM_W_UNT.R

FP_NADM_W_UNTR Documentation

FP_NADM_W_UNT #unmet_family IRdata Married women with an unmet need for family planning for spacing and limiting, line 17 manually added by Qianyu

Description

FP_NADM_W_UNT #unmet_family IRdata Married women with an unmet need for family planning for spacing and limiting, line 17 manually added by Qianyu

Usage

FP_NADM_W_UNT(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "FP_NADM_W_UNT", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.