View source: R/FP_NDYA_W_PDM.R
| FP_NDYA_W_PDM | R Documentation |
FP_NADA_W_UNT IRdata Women with an unmet need for family planning for spacing and limiting
FP_NDYA_W_PDM(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "FP_NDYA_W_PDM",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::FP_NDYA_W_PDM)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.