HA_CATH_W_NRS: HA_CATH_W_NRS

View source: R/HA_CATH_W_NRS.R

HA_CATH_W_NRSR Documentation

HA_CATH_W_NRS

Description

HA_CATH_W_NRS

Usage

HA_CATH_W_NRS(IRdata)

Arguments

IRdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 

## Not run: 

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "HA_CATH_W_NRS", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.