View source: R/HA_KAID_W_HRD.R
| HA_KAID_W_HRD | R Documentation |
HA_KAID_W_HRD Percentage of women who have heard of HIV or AIDS hk_ever_heard in github IR
HA_KAID_W_HRD(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "HA_KAID_W_HRD", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.