HA_STIS_W_STI: HA_STIS_W_STI Percentage of women reporting a sexually...

View source: R/HA_STIS_W_STI.R

HA_STIS_W_STIR Documentation

HA_STIS_W_STI Percentage of women reporting a sexually transmitted infection in the 12 months preceding the survey among women who ever had sexual intercourse hk_sti in github IR

Description

HA_STIS_W_STI Percentage of women reporting a sexually transmitted infection in the 12 months preceding the survey among women who ever had sexual intercourse hk_sti in github IR

Usage

HA_STIS_W_STI(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "HA_STIS_W_STI", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.