View source: R/HC_FLRM_H_CER.R
| HC_FLRM_H_CER | R Documentation |
HC_FLRM_H_CER Percentage of households with ceramic tile floors ph_floor in github HR
HC_FLRM_H_CER(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "HC_FLRM_H_CER", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.