HC_WIXQ_P_12Q: HC_WIXQ_P_12Q PRdata Population in the lowest and second...

View source: R/HC_WIXQ_P_12Q.R

HC_WIXQ_P_12QR Documentation

HC_WIXQ_P_12Q PRdata Population in the lowest and second wealth quintile

Description

HC_WIXQ_P_12Q PRdata Population in the lowest and second wealth quintile

Usage

HC_WIXQ_P_12Q(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "FP_CUSA_W_MOD",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::fp_cruse_mod)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.