MA_MBAG_W_B18: ##' MA_MBAG_W_B18 Percentage of women first married by exact...

View source: R/MA_MBAG_W_B18.R

MA_MBAG_W_B18R Documentation

##' MA_MBAG_W_B18 Percentage of women first married by exact age 18 ms_afm_18 in github IR

Description

##' MA_MBAG_W_B18 Percentage of women first married by exact age 18 ms_afm_18 in github IR

Usage

MA_MBAG_W_B18(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "MA_MBAG_W_B18", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.