View source: R/ML_NETC_C_ITN.R
| ML_NETC_C_ITN | R Documentation |
ML_NETC_C_ITN PRdata Percentage of children under age five who slept under an insecticide treated net (ITN) the night before the survey
ML_NETC_C_ITN(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "FP_CUSA_W_MOD",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::fp_cruse_mod)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.