ML_NETU_P_ITN: ML_NETU_P_ITN PRdata Percentage of the de facto household...

View source: R/ML_NETU_P_ITN.R

ML_NETU_P_ITNR Documentation

ML_NETU_P_ITN PRdata Percentage of the de facto household population who slept under an insecticide treated net the night before the survey

Description

ML_NETU_P_ITN PRdata Percentage of the de facto household population who slept under an insecticide treated net the night before the survey

Usage

ML_NETU_P_ITN(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "FP_CUSA_W_MOD",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::fp_cruse_mod)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.