WS_SRCE_H_USG: WS_SRCE_H_USG Percentage of households whose main source of...

View source: R/WS_SRCE_H_USG.R

WS_SRCE_H_USGR Documentation

WS_SRCE_H_USG Percentage of households whose main source of drinking water is an unprotected spring ph_wtr_source in github "unprotected spring" = 42, HR

Description

WS_SRCE_H_USG Percentage of households whose main source of drinking water is an unprotected spring ph_wtr_source in github "unprotected spring" = 42, HR

Usage

WS_SRCE_H_USG(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Miaolei Bao, Yunhan Wu, Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia", indicator = "WS_SRCE_H_USG", year = 2018)

## End(Not run)


surveyPrev documentation built on June 19, 2026, 5:06 p.m.