WS_TLET_H_IMP: WS_TLET_H_IMP PRdata Percentage of households using an...

View source: R/WS_TLET_H_IMP.R

WS_TLET_H_IMPR Documentation

WS_TLET_H_IMP PRdata Percentage of households using an improved sanitation facility

Description

WS_TLET_H_IMP PRdata Percentage of households using an improved sanitation facility

Usage

WS_TLET_H_IMP(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "WS_TLET_H_IMP",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::WS_TLET_H_IMP)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.