WS_TLET_P_BAS: WS_TLET_P_BAS PRdata Population with access to a basic...

View source: R/WS_TLET_P_BAS.R

WS_TLET_P_BASR Documentation

WS_TLET_P_BAS PRdata Population with access to a basic sanitation service

Description

WS_TLET_P_BAS PRdata Population with access to a basic sanitation service

Usage

WS_TLET_P_BAS(Rdata)

Arguments

Rdata

data.frame from surveyPrev::getDHSdata

Value

A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator

Author(s)

Qianyu Dong

Examples

## Not run: 
dhsData <- getDHSdata(country = "Zambia",
                                 indicator = "WS_TLET_P_BAS",
                                 year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
                         FUN = surveyPrev::WS_TLET_P_BAS)

## End(Not run)

surveyPrev documentation built on June 19, 2026, 5:06 p.m.