View source: R/CM_ECMR_C_IMF.R
| CM_ECMR_C_IMF | R Documentation |
BR
CM_ECMR_C_IMF(Rdata, mort.cut = c(1, 2, 6, 12, 24, 36, 48, 60), mort.year = 5)
Rdata |
data.frame from surveyPrev::getDHSdata |
mort.cut |
age group cutoffs for hazard calculation. Constant hazards are assumed to be within the specified cutoffs. |
mort.year |
The number of years preceding survey. Set to be 5. |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "CM_ECMR_C_IMF", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.