View source: R/CM_ECMR_C_NNR.R
| CM_ECMR_C_NNR | R Documentation |
CM_ECMR_C_NNR BRdata Neonatal mortality rate
CM_ECMR_C_NNR(Rdata, nmr.year = 10)
Rdata |
data.frame from surveyPrev::getDHSdata |
nmr.year |
This is an argument specifically for NMR calculation. It specifies births how many years do we include prior to the date of survey. Default to be 10, i.e., NMR in the last 10 years prior to survey. |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "CM_ECMR_C_NNR",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::CM_ECMR_C_NNR)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.