View source: R/CN_ANMC_C_ANY.R
| CN_ANMC_C_ANY | R Documentation |
CN_ANMC_C_ANY PRdata Children with any anemia Children under five with any anemia
CN_ANMC_C_ANY(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "CN_ANMC_C_ANY",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::CN_ANMC_C_ANY)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.