View source: R/DV_AFSV_W_A10.R
| DV_AFSV_W_A10 | R Documentation |
DV_AFSV_W_A10
DV_AFSV_W_A10(IRdata)
IRdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "DV_AFSV_W_A10", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.