View source: R/FP_NADM_W_UNT.R
| FP_NADM_W_UNT | R Documentation |
FP_NADM_W_UNT #unmet_family IRdata Married women with an unmet need for family planning for spacing and limiting, line 17 manually added by Qianyu
FP_NADM_W_UNT(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "FP_NADM_W_UNT", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.