View source: R/HA_CATH_W_NRS.R
| HA_CATH_W_NRS | R Documentation |
HA_CATH_W_NRS
HA_CATH_W_NRS(IRdata)
IRdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Miaolei Bao, Yunhan Wu, Qianyu Dong
## Not run:
## Not run:
## Not run:
dhsData <- getDHSdata(country = "Zambia", indicator = "HA_CATH_W_NRS", year = 2018)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.