View source: R/WS_TLET_H_IMP.R
| WS_TLET_H_IMP | R Documentation |
WS_TLET_H_IMP PRdata Percentage of households using an improved sanitation facility
WS_TLET_H_IMP(Rdata)
Rdata |
data.frame from surveyPrev::getDHSdata |
A partially processed data.frame that will be used in surveyPrev::getDHSindicator. The whole function can be used as a parameter in surveyPrev::getDHSindicator
Qianyu Dong
## Not run:
dhsData <- getDHSdata(country = "Zambia",
indicator = "WS_TLET_H_IMP",
year = 2018)
data <- getDHSindicator(dhsData, indicator = NULL,
FUN = surveyPrev::WS_TLET_H_IMP)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.